==> blesta-5.10.2.zip: blesta/core/Automation/Tasks/Task/language/de_de/cleanup_logs.php <==
<?php
/**
 * Cleanup Logs
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Automation.task.cleanup_logs.logs_cron_deleted'] = '%1$s alte Cron-Protokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_transaction_deleted'] = '%1$s alte Transaktionsprotokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_service_deleted'] = '%1$s alte Serviceprotokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_client_settings_deleted'] = '%1$s alte Client-Einstellungsprotokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_user_deleted'] = '%1$s alte Benutzerprotokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_messenger_deleted'] = '%1$s alte Messenger-Protokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_email_deleted'] = '%1$s alte E-Mail-Protokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_contact_deleted'] = '%1$s alte Kontaktprotokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_accountaccess_deleted'] = '%1$s alte Kontozugriffsprotokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_module_deleted'] = '%1$s alte Modulprotokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_gateway_deleted'] = '%1$s alte Gateway-Protokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.completed'] = 'Die Aufgabe "Protokolle bereinigen" ist abgeschlossen.';
$lang['Automation.task.cleanup_logs.attempt'] = 'Ich versuche, alte Protokolle zu bereinigen.';

==> blesta-5.11.4.zip: blesta/core/Automation/Tasks/Task/language/de_de/cleanup_logs.php <==
<?php
/**
 * Cleanup Logs
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Automation.task.cleanup_logs.logs_cron_deleted'] = '%1$s alte Cron-Protokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_transaction_deleted'] = '%1$s alte Transaktionsprotokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_service_deleted'] = '%1$s alte Serviceprotokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_client_settings_deleted'] = '%1$s alte Client-Einstellungsprotokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_user_deleted'] = '%1$s alte Benutzerprotokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_messenger_deleted'] = '%1$s alte Messenger-Protokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_email_deleted'] = '%1$s alte E-Mail-Protokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_contact_deleted'] = '%1$s alte Kontaktprotokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_accountaccess_deleted'] = '%1$s alte Kontozugriffsprotokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_module_deleted'] = '%1$s alte Modulprotokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.logs_gateway_deleted'] = '%1$s alte Gateway-Protokolle wurden gelöscht.';
$lang['Automation.task.cleanup_logs.completed'] = 'Die Aufgabe "Protokolle bereinigen" ist abgeschlossen.';
$lang['Automation.task.cleanup_logs.attempt'] = 'Ich versuche, alte Protokolle zu bereinigen.';
$lang['Automation.task.cleanup_logs.logs_service_changes_deleted'] = '%1$s Die alten Service Changes-Protokolle wurden gelöscht.';
